@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: EnumTypeWrapper.java 887 2009-02-10 13:15:15Z maxberger $ */
+/* $Id: EnumTypeWrapper.java,v aa78526a6b7b 2009/06/03 10:50:27 maxberger $ */
 
 package net.sourceforge.jeuclid.context.typewrapper;
 
@@ -23,7 +23,7 @@ import java.lang.reflect.InvocationTargetException;
 /**
  * Converting String to Enum and vice versa is easy with help of Enum class.
  * 
- * @version $Revision: 887 $
+ * @version $Revision: aa78526a6b7b $
  */
 public final class EnumTypeWrapper extends AbstractSimpleTypeWrapper {
     private static final String FAILED_TO_RETRIEVE_VALUES_OF_ENUM_CLASS = "Failed to retrieve values of enum class ";
@@ -60,8 +60,7 @@ public final class EnumTypeWrapper extends AbstractSimpleTypeWrapper {
         if (value == null) {
             return null;
         }
-        final Object o = Enum.valueOf((Class) this.getValueType(), value);
-        return o;
+        return Enum.valueOf((Class) this.getValueType(), value);
     }
 
     /**
