@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractInvisibleJEuclidElement.java 518 2007-09-14 08:29:58Z maxberger $ */
+/* $Id: AbstractInvisibleJEuclidElement.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements;
 
@@ -23,19 +23,27 @@ import java.util.List;
 
 import net.sourceforge.jeuclid.layout.LayoutableNode;
 
+import org.apache.batik.dom.AbstractDocument;
+
 /**
  * Represents a MathElement with no content.
  * 
- * @version $Revision: 518 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 public abstract class AbstractInvisibleJEuclidElement extends
         AbstractJEuclidElement {
+
     /**
-     * Default Constructor.
+     * Default constructor. Sets MathML Namespace.
      * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public AbstractInvisibleJEuclidElement() {
-        super();
+    public AbstractInvisibleJEuclidElement(final String qname,
+            final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
