@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: MathImpl.java,v 38db1a498ca5 2009/09/25 20:17:03 max $ */
+/* $Id: MathImpl.java,v c169040ef426 2009/10/28 09:55:31 max $ */
 
 package net.sourceforge.jeuclid.elements.generic;
 
@@ -31,7 +31,7 @@ import org.w3c.dom.mathml.MathMLMathElement;
 /**
  * The root element for creating a MathElement tree.
  * 
- * @version $Revision: 38db1a498ca5 $
+ * @version $Revision: c169040ef426 $
  */
 public final class MathImpl extends AbstractContainer implements
         MathMLMathElement {
@@ -67,18 +67,26 @@ public final class MathImpl extends AbstractContainer implements
             if ((s0 != null) && (s0.length() > 0)) {
                 retVal = which.fromString(s0);
             } else {
-                // Support old namespace
-                final String s = MathImpl.this.getAttributeNS(
-                        Constants.NS_OLD_JEUCLID_EXT, which.getOptionName());
-                if ((s != null) && (s.length() > 0)) {
-                    retVal = which.fromString(s);
-                } else {
-                    // Support deprecated attributes
-                    final String s2 = MathImpl.this.getAttributeNS(
-                            Constants.NS_OLD_JEUCLID_EXT, which.toString());
-                    if ((s2 != null) && (s2.length() > 0)) {
-                        retVal = which.fromString(s2);
-                    }
+                retVal = this.getDeprecatedParamValuesFromJEuclidExt(which,
+                        retVal);
+            }
+            return retVal;
+        }
+
+        private Object getDeprecatedParamValuesFromJEuclidExt(
+                final Parameter which, final Object currentValue) {
+            // old namespace
+            Object retVal = currentValue;
+            final String s = MathImpl.this.getAttributeNS(
+                    Constants.NS_OLD_JEUCLID_EXT, which.getOptionName());
+            if ((s != null) && (s.length() > 0)) {
+                retVal = which.fromString(s);
+            } else {
+                // Support deprecated attributes
+                final String s2 = MathImpl.this.getAttributeNS(
+                        Constants.NS_OLD_JEUCLID_EXT, which.toString());
+                if ((s2 != null) && (s2.length() > 0)) {
+                    retVal = which.fromString(s2);
                 }
             }
             return retVal;
