@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: Menclose.java,v cae99f384592 2009/06/03 12:42:28 maxberger $ */
+/* $Id: Menclose.java,v 353eda94b8dd 2009/10/14 12:04:09 max $ */
 
 package net.sourceforge.jeuclid.elements.presentation.general;
 
@@ -54,11 +54,21 @@ import org.w3c.dom.mathml.MathMLEncloseElement;
 /**
  * Class for supporting "menclose" elements.
  * 
- * @version $Revision: cae99f384592 $
+ * @version $Revision: 353eda94b8dd $
  */
 public final class Menclose extends AbstractElementWithDelegates implements
         MathMLEncloseElement {
 
+    /**
+     * The XML element from this class.
+     */
+    public static final String ELEMENT = "menclose";
+
+    /** The notation attribute. */
+    public static final String ATTR_NOTATION = "notation";
+
+    private static final String LONGDIV = "longdiv";
+
     /**
      * base class for all row-like notations.
      * 
@@ -66,6 +76,11 @@ public final class Menclose extends AbstractElementWithDelegates implements
     private abstract static class AbstractRowLikeNotation extends
             AbstractContainer {
 
+        /**
+         * No data, so SUID is does not matter.
+         */
+        private static final long serialVersionUID = 1L;
+
         /**
          * Default constructor. Sets MathML Namespace.
          * 
@@ -318,14 +333,6 @@ public final class Menclose extends AbstractElementWithDelegates implements
 
     }
 
-    /**
-     * The XML element from this class.
-     */
-    public static final String ELEMENT = "menclose";
-
-    /** The notation attribute. */
-    public static final String ATTR_NOTATION = "notation";
-
     /**
      * Logger for this class
      */
@@ -346,7 +353,7 @@ public final class Menclose extends AbstractElementWithDelegates implements
     public Menclose(final String qname, final AbstractDocument odoc) {
         super(qname, odoc);
 
-        this.setDefaultMathAttribute(Menclose.ATTR_NOTATION, "");
+        this.setDefaultMathAttribute(Menclose.ATTR_NOTATION, Menclose.LONGDIV);
     }
 
     /** {@inheritDoc} */
@@ -447,7 +454,7 @@ public final class Menclose extends AbstractElementWithDelegates implements
         try {
             Menclose.IMPL_CLASSES.put("radical", Msqrt.class.getConstructor(
                     String.class, AbstractDocument.class));
-            Menclose.IMPL_CLASSES.put("longdiv", Menclose.Longdiv.class
+            Menclose.IMPL_CLASSES.put(Menclose.LONGDIV, Menclose.Longdiv.class
                     .getConstructor(String.class, AbstractDocument.class));
             Menclose.IMPL_CLASSES.put("updiagonalstrike",
                     Menclose.Updiagonalstrike.class.getConstructor(
