@@ -14,18 +14,19 @@
  * limitations under the License.
  */
 
-/* $Id: Mrow.java 752 2008-05-19 12:40:13Z maxberger $ */
+/* $Id: Mrow.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.general;
 
 import net.sourceforge.jeuclid.elements.presentation.AbstractContainer;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.w3c.dom.Node;
 
 /**
  * This class presents a row.
  * 
- * @version $Revision: 752 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 public final class Mrow extends AbstractContainer {
 
@@ -37,16 +38,21 @@ public final class Mrow extends AbstractContainer {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Creates a math element.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mrow() {
-        super();
+    public Mrow(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mrow();
+        return new Mrow(this.nodeName, this.ownerDocument);
     }
 
 }
