@@ -14,18 +14,19 @@
  * limitations under the License.
  */
 
-/* $Id: Mprescripts.java 718 2008-04-28 18:46:38Z maxberger $ */
+/* $Id: Mprescripts.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.script;
 
 import net.sourceforge.jeuclid.elements.AbstractInvisibleJEuclidElement;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.w3c.dom.Node;
 
 /**
  * This class represent the empty elements mprescripts.
  * 
- * @version $Revision: 718 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 public final class Mprescripts extends AbstractInvisibleJEuclidElement {
 
@@ -37,15 +38,20 @@ public final class Mprescripts extends AbstractInvisibleJEuclidElement {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Creates a math element.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mprescripts() {
-        super();
+    public Mprescripts(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mprescripts();
+        return new Mprescripts(this.nodeName, this.ownerDocument);
     }
 }
