@@ -14,24 +14,31 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractTableElement.java 887 2009-02-10 13:15:15Z maxberger $ */
+/* $Id: AbstractTableElement.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.table;
 
 import net.sourceforge.jeuclid.elements.presentation.AbstractContainer;
 
+import org.apache.batik.dom.AbstractDocument;
+
 /**
- * Common functionality for all Table elements. This class contains support
- * for setting and getting alignment attributes.
+ * Common functionality for all Table elements. This class contains support for
+ * setting and getting alignment attributes.
  * 
- * @version $Revision: 887 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 public abstract class AbstractTableElement extends AbstractContainer {
     /**
-     * Default Constructor.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public AbstractTableElement() {
-        super();
+    public AbstractTableElement(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /**
