@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: Mtable.java 795 2008-06-21 10:53:35Z maxberger $ */
+/* $Id: Mtable.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.table;
 
@@ -42,6 +42,7 @@ import net.sourceforge.jeuclid.layout.LayoutView;
 import net.sourceforge.jeuclid.layout.LayoutableNode;
 import net.sourceforge.jeuclid.layout.LineObject;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Node;
@@ -54,7 +55,7 @@ import org.w3c.dom.mathml.MathMLTableRowElement;
 /**
  * This class presents a table.
  * 
- * @version $Revision: 795 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 // CHECKSTYLE:OFF
 // Data abstraction coupling is "to high". but this is necessary for proper
@@ -289,10 +290,16 @@ public final class Mtable extends AbstractTableElement implements
     }
 
     /**
-     * Creates a math element.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mtable() {
-        super();
+    public Mtable(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
+
         this.setDefaultMathAttribute(Mtable.ATTR_ALIGN,
                 Mtable.VAlign.VALUE_AXIS);
         this.setDefaultMathAttribute(Mtable.ATTR_ROWALIGN,
@@ -329,7 +336,7 @@ public final class Mtable extends AbstractTableElement implements
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mtable();
+        return new Mtable(this.nodeName, this.ownerDocument);
     }
 
     /** {@inheritDoc} */
