@@ -14,16 +14,17 @@
  * limitations under the License.
  */
 
-/* $Id: Mtr.java 718 2008-04-28 18:46:38Z maxberger $ */
+/* $Id: Mtr.java,v bc1d5fde7b73 2009/06/01 14:40:54 maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.table;
 
+import org.apache.batik.dom.AbstractDocument;
 import org.w3c.dom.Node;
 
 /**
  * This class presents a row in MathTable.
  * 
- * @version $Revision: 718 $
+ * @version $Revision: bc1d5fde7b73 $
  */
 public final class Mtr extends AbstractTableRow {
 
@@ -35,16 +36,21 @@ public final class Mtr extends AbstractTableRow {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Creates a math element.
+     * Default constructor. Sets MathML Namespace.
+     * 
+     * @param qname
+     *            Qualified name.
+     * @param odoc
+     *            Owner Document.
      */
-    public Mtr() {
-        super();
+    public Mtr(final String qname, final AbstractDocument odoc) {
+        super(qname, odoc);
     }
 
     /** {@inheritDoc} */
     @Override
     protected Node newNode() {
-        return new Mtr();
+        return new Mtr(this.nodeName, this.ownerDocument);
     }
 
 }
