@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: StringUtil.java,v 923658a2b249 2009/09/11 09:57:31 max $ */
+/* $Id: StringUtil.java,v 480d7f8c8b4e 2010/02/12 14:18:45 max $ */
 
 package net.sourceforge.jeuclid.elements.support.text;
 
@@ -45,7 +45,7 @@ import org.w3c.dom.NodeList;
 /**
  * Utilities for String handling.
  * 
- * @version $Revision: 923658a2b249 $
+ * @version $Revision: 480d7f8c8b4e $
  */
 // CHECKSTYLE:OFF
 // Data Abstraction Coupling is too high. Hover, String handling is not
@@ -261,8 +261,12 @@ public final class StringUtil {
             theLayout = new TextLayout(" ", new Font("", 0, 0),
                     realFontRenderContext);
         } else {
-            theLayout = new TextLayout(aString.getIterator(),
-                    realFontRenderContext);
+            synchronized (TextLayout.class) {
+                // Catches a rare NullPointerException in
+                // sun.font.FileFontStrike.getCachedGlyphPtr(FileFontStrike.java:448)
+                theLayout = new TextLayout(aString.getIterator(),
+                        realFontRenderContext);
+            }
         }
         return theLayout;
     }
