@@ -14,10 +14,12 @@
  * limitations under the License.
  */
 
-/* $Id: LayoutTest.java 902 2009-03-20 11:32:25Z maxberger $ */
+/* $Id: LayoutTest.java,v a9320f31de60 2009/04/10 12:26:03 maxberger $ */
 
 package net.sourceforge.jeuclid.test;
 
+import java.util.List;
+
 import net.sourceforge.jeuclid.DOMBuilder;
 import net.sourceforge.jeuclid.MathMLParserSupport;
 import net.sourceforge.jeuclid.elements.presentation.general.Mfrac;
@@ -29,6 +31,7 @@ import net.sourceforge.jeuclid.layout.LayoutableNode;
 
 import org.testng.Assert;
 import org.testng.annotations.Test;
+import org.w3c.dom.Node;
 import org.w3c.dom.mathml.MathMLDocument;
 import org.w3c.dom.mathml.MathMLFractionElement;
 import org.w3c.dom.mathml.MathMLMathElement;
@@ -37,15 +40,15 @@ import org.w3c.dom.mathml.MathMLPresentationToken;
 import org.w3c.dom.views.DocumentView;
 
 /**
- * @version $Revision: 902 $
+ * @version $Revision: a9320f31de60 $
  */
 public class LayoutTest {
 
     /**
      * Test string with xml header.
      */
-    final public static String TEST1 = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\">"
-            + "<mrow><mo>(</mo><mn>5</mn></mrow></math>";
+    final static public String TEST1 = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><math mode=\"display\">"
+            + "<mrow><mo>(</mo><mn>555</mn></mrow></math>";
 
     /**
      * Test if there is something in the view.
@@ -159,7 +162,7 @@ public class LayoutTest {
     }
 
     /**
-     * Test MO without parent.
+     * Test MO without math parent.
      * 
      * @throws Exception
      *             if the test fails.
@@ -177,4 +180,45 @@ public class LayoutTest {
         // To trigger layout
         view.getWidth();
     }
+
+    /**
+     * Test MO without any parent.
+     * 
+     * @throws Exception
+     *             if the test fails.
+     */
+    @Test
+    public void testMoWithoutParent2() throws Exception {
+        final MathMLDocument docElement = DOMBuilder.getInstance()
+                .createJeuclidDom(
+                        MathMLParserSupport.parseString("<mo>&#x2211;</mo>"));
+        final JEuclidView view = (JEuclidView) (((DocumentView) docElement)
+                .getDefaultView());
+
+        // To trigger layout
+        view.getWidth();
+    }
+
+    /**
+     * Test if getNodesAt() works.
+     * 
+     * @throws Exception
+     *             if the test fails.
+     */
+    @Test
+    public void testGetNodesAt() throws Exception {
+        final MathMLDocument docElement = DOMBuilder.getInstance()
+                .createJeuclidDom(
+                        MathMLParserSupport.parseString(LayoutTest.TEST1));
+        final JEuclidView view = (JEuclidView) (((DocumentView) docElement)
+                .getDefaultView());
+        final List<JEuclidView.NodeRect> rlist = view.getNodesAt(15, 0, 0, 0);
+        Assert.assertSame(rlist.get(0).getNode(), docElement);
+        final Node math = docElement.getFirstChild();
+        Assert.assertSame(rlist.get(1).getNode(), math);
+        final Node mrow = math.getFirstChild();
+        Assert.assertSame(rlist.get(2).getNode(), mrow);
+        final Node five = mrow.getFirstChild().getNextSibling();
+        Assert.assertSame(rlist.get(3).getNode(), five);
+    }
 }
