@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: PreloaderMathML.java 887 2009-02-10 13:15:15Z maxberger $ */
+/* $Id: PreloaderMathML.java,v 32023847f457 2009/03/20 14:20:15 maxberger $ */
 
 package net.sourceforge.jeuclid.xmlgraphics;
 
@@ -25,6 +25,7 @@ import java.io.IOException;
 import java.io.InputStream;
 
 import javax.xml.transform.Source;
+import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamSource;
 
 import net.sourceforge.jeuclid.Constants;
@@ -49,7 +50,7 @@ import org.w3c.dom.Element;
 import org.xml.sax.SAXException;
 
 /**
- * @version $Revision: 887 $
+ * @version $Revision: 32023847f457 $
  */
 public class PreloaderMathML extends AbstractImagePreloader {
     /**
@@ -114,10 +115,16 @@ public class PreloaderMathML extends AbstractImagePreloader {
         Document n = null;
         InputStream in = null;
         try {
-            in = new UnclosableInputStream(ImageUtil.needInputStream(src));
-            final int length = in.available();
-            in.mark(length + 1);
-            n = Parser.getInstance().parseStreamSource(new StreamSource(in));
+            if (src instanceof DOMSource) {
+                final DOMSource domSrc = (DOMSource) src;
+                n = (Document) domSrc.getNode();
+            } else {
+                in = new UnclosableInputStream(ImageUtil.needInputStream(src));
+                final int length = in.available();
+                in.mark(length + 1);
+                n = Parser.getInstance().parseStreamSource(
+                        new StreamSource(in));
+            }
             final Element rootNode = n.getDocumentElement();
             if (!(AbstractJEuclidElement.URI.equals(rootNode
                     .getNamespaceURI()) || MathImpl.ELEMENT.equals(rootNode
