@@ -14,11 +14,12 @@
  * limitations under the License.
  */
 
-/* $Id: MainFrame.java 892 2009-02-17 12:35:15Z maxberger $ */
+/* $Id: MainFrame.java,v 9fcde7bec879 2009/04/04 20:27:55 maxberger $ */
 
 package net.sourceforge.jeuclid.app.mathviewer;
 
 import java.awt.BorderLayout;
+import java.awt.Color;
 import java.awt.Point;
 import java.awt.Toolkit;
 import java.awt.datatransfer.DataFlavor;
@@ -43,6 +44,8 @@ import javax.swing.JSplitPane;
 import javax.swing.JTextArea;
 import javax.swing.KeyStroke;
 import javax.swing.ScrollPaneConstants;
+import javax.swing.event.DocumentEvent;
+import javax.swing.event.DocumentListener;
 
 import net.sourceforge.jeuclid.MathMLSerializer;
 import net.sourceforge.jeuclid.context.LayoutContextImpl;
@@ -54,7 +57,7 @@ import org.w3c.dom.Document;
 /**
  * Main frame for the MathViewer application.
  * 
- * @version $Revision: 892 $
+ * @version $Revision: 9fcde7bec879 $
  */
 // CHECKSTYLE:OFF
 public class MainFrame extends JFrame {
@@ -428,11 +431,46 @@ public class MainFrame extends JFrame {
     private JTextArea getTextArea() {
         if (this.textArea == null) {
             this.textArea = new JTextArea();
-            this.textArea.setEditable(false);
+            this.textArea.setText("<?xml version='1.0'?>\n"
+                    + "<math xmlns='http://www.w3.org/1998/Math/MathML'>\n"
+                    + "</math>");
+            this.textArea.setEditable(true);
+            this.textArea.getDocument().addDocumentListener(
+                    new DocumentListener() {
+
+                        public void changedUpdate(
+                                final DocumentEvent documentevent) {
+                            MainFrame.this.updateFromTextArea();
+                        }
+
+                        public void insertUpdate(
+                                final DocumentEvent documentevent) {
+                            MainFrame.this.updateFromTextArea();
+                        }
+
+                        public void removeUpdate(
+                                final DocumentEvent documentevent) {
+                            MainFrame.this.updateFromTextArea();
+                        }
+                    });
+            this.textArea.setBackground(Color.WHITE);
         }
         return this.textArea;
     }
 
+    private void updateFromTextArea() {
+        try {
+            this.getMathComponent().setContent(this.getTextArea().getText());
+            this.textArea.setForeground(Color.BLACK);
+            // CHECKSTYLE:OFF
+            // in this case, we want to explicitly provide catch-all error
+            // handling.
+        } catch (final RuntimeException e) {
+            // CHECKSTYLE:ON
+            this.textArea.setForeground(Color.RED);
+        }
+    }
+
     /**
      * This method initializes scrollPane
      * 
@@ -484,6 +522,7 @@ public class MainFrame extends JFrame {
             this.mathComponent
                     .setContent("<math><mtext>" //$NON-NLS-1$
                             + Messages.getString("MathViewer.noFileLoaded") + "</mtext></math>"); //$NON-NLS-1$ //$NON-NLS-2$
+            this.mathComponent.setFocusable(true);
         }
         return this.mathComponent;
     }
@@ -685,8 +724,8 @@ public class MainFrame extends JFrame {
             try {
                 final String newContent = (String) content
                         .getTransferData(DataFlavor.stringFlavor);
-                this.mathComponent.setContent(newContent);
-                this.textArea.setText(newContent);
+                this.getMathComponent().setContent(newContent);
+                this.getTextArea().setText(newContent);
                 // CHECKSTYLE:OFF
                 // in this case, we want to explicitly provide catch-all error
                 // handling.
